==> qtjambi-datavisualization-5.15.16-sources.jar: io/qt/datavis/QScatterDataArray.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Template class that provides a dynamic array</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qvector.html">QtDataVisualization::QScatterDataArray</a></code></p>
 */
public class QScatterDataArray extends io.qt.core.QVector<io.qt.datavis.@NonNull QScatterDataItem>
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QtDataVisualization::QScatterDataArray::<wbr>QScatterDataArray()</code></p>
     */
    public QScatterDataArray(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QScatterDataArray instance);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QScatterDataArray(QPrivateConstructor p) { super(p); } 
    

    /**
     * Returns the objects's hash code computed by <code>qHash(QtDataVisualization::QScatterDataArray)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QScatterDataArray clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QScatterDataArray clone_native(long __this_nativeId);
}

==> qtjambi-datavisualization-6.6.0-sources.jar: io/qt/datavis/QScatterDataArray.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Template class that provides a dynamic array</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qlist.html">QScatterDataArray</a></code></p>
 */
public class QScatterDataArray extends io.qt.core.QList<io.qt.datavis.@NonNull QScatterDataItem>
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QScatterDataArray::<wbr>QScatterDataArray()</code></p>
     */
    public QScatterDataArray(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QScatterDataArray instance);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QScatterDataArray(QPrivateConstructor p) { super(p); } 
    

    /**
     * Returns the objects's hash code computed by <code>qHash(QScatterDataArray)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QScatterDataArray clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QScatterDataArray clone_native(long __this_nativeId);
}
